==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServicePlace.md <==
# AmazonLocationServicePlace


```text
aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServicePlace
```

```text
include('aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServicePlace')
```



| Illustration | AmazonLocationServicePlace | AmazonLocationServicePlaceCard | AmazonLocationServicePlaceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServicePlace.png) | ![illustration for AmazonLocationServicePlace](../../../aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServicePlace.Local.png) | ![illustration for AmazonLocationServicePlaceCard](../../../aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServicePlaceCard.Local.png) | ![illustration for AmazonLocationServicePlaceGroup](../../../aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServicePlaceGroup.Local.png) |




## AmazonLocationServicePlace

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonLocationServicePlace
include('aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServicePlace')

' renders the element
AmazonLocationServicePlace('AmazonLocationServicePlace', 'Amazon Location Service Place', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonLocationServicePlace
include('aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServicePlace')

' renders the element
AmazonLocationServicePlace('AmazonLocationServicePlace', 'Amazon Location Service Place', 'an optional tech label')
@enduml
```

## AmazonLocationServicePlaceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonLocationServicePlaceCard
include('aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServicePlace')

' renders the element
AmazonLocationServicePlaceCard('AmazonLocationServicePlaceCard', 'Amazon Location Service Place Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonLocationServicePlaceCard
include('aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServicePlace')

' renders the element
AmazonLocationServicePlaceCard('AmazonLocationServicePlaceCard', 'Amazon Location Service Place Card', 'an optional description')
@enduml
```

## AmazonLocationServicePlaceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonLocationServicePlaceGroup
include('aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServicePlace')

' renders the element
AmazonLocationServicePlaceGroup('AmazonLocationServicePlaceGroup', 'Amazon Location Service Place Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonLocationServicePlaceGroup
include('aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServicePlace')

' renders the element
AmazonLocationServicePlaceGroup('AmazonLocationServicePlaceGroup', 'Amazon Location Service Place Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServicePlace.md <==
# AmazonLocationServicePlace


```text
aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServicePlace
```

```text
include('aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServicePlace')
```



| Illustration | AmazonLocationServicePlace | AmazonLocationServicePlaceCard | AmazonLocationServicePlaceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServicePlace.png) | ![illustration for AmazonLocationServicePlace](../../../aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServicePlace.Local.png) | ![illustration for AmazonLocationServicePlaceCard](../../../aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServicePlaceCard.Local.png) | ![illustration for AmazonLocationServicePlaceGroup](../../../aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServicePlaceGroup.Local.png) |




## AmazonLocationServicePlace

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonLocationServicePlace
include('aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServicePlace')

' renders the element
AmazonLocationServicePlace('AmazonLocationServicePlace', 'Amazon Location Service Place', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonLocationServicePlace
include('aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServicePlace')

' renders the element
AmazonLocationServicePlace('AmazonLocationServicePlace', 'Amazon Location Service Place', 'an optional tech label')
@enduml
```

## AmazonLocationServicePlaceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonLocationServicePlaceCard
include('aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServicePlace')

' renders the element
AmazonLocationServicePlaceCard('AmazonLocationServicePlaceCard', 'Amazon Location Service Place Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonLocationServicePlaceCard
include('aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServicePlace')

' renders the element
AmazonLocationServicePlaceCard('AmazonLocationServicePlaceCard', 'Amazon Location Service Place Card', 'an optional description')
@enduml
```

## AmazonLocationServicePlaceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonLocationServicePlaceGroup
include('aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServicePlace')

' renders the element
AmazonLocationServicePlaceGroup('AmazonLocationServicePlaceGroup', 'Amazon Location Service Place Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonLocationServicePlaceGroup
include('aws-20210730/Resource/FrontEndWebMobile/AmazonLocationServicePlace')

' renders the element
AmazonLocationServicePlaceGroup('AmazonLocationServicePlaceGroup', 'Amazon Location Service Place Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
